selexe
=========

What It Does
-------------

selexe is a tool to directly execute selenese files (i.e. `*.sel` files) created by the selenium IDE. Selenium commands
are directly translated into Python executable code without the need of manually converting selenese files into Python
code first.


Changes
----------------
* V 0.1.0 (2012-01-08) Initial version


Supported Platforms
----------------------------

This package has been mainly developed under Linux, and hence should run on all standard unix platforms, as well
as on Mac OS X.

It has been tested run with Python 2.6.x and 2.7.x. Python 3.x should also be supported.


License
-------

selexe has been written by `Ralph Heinkel (www.ralph-heinkel.com) <http://www.ralph-heinkel.com/>`_ and is
released under `MIT license <http://packages.python.org/selexe/license.html>`_.


Quick Installation
-------------------

From your unix/windows command line run::

    easy_install selexe
   
or download the tar.gz or zip package. After unpacking run `python setup.py install` from your command line. 

Documentation
----------------

Documentation can be found at `<http://packages.python.org/selexe/>`_.


Support
--------

For discussion of selexe issues and getting help please use the Google newsgroup
available at `<http://groups.google.com/group/selexe>`_.


Missing Features
-----------------
* Lots, it is not finished by far!
